# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.bgp_config import BgpConfig

class TestBgpConfig(unittest.TestCase):
    """BgpConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BgpConfig:
        """Test BgpConfig
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BgpConfig`
        """
        model = BgpConfig()
        if include_optional:
            return BgpConfig(
                asn = 65000,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                deployment_type = 'local',
                href = '',
                id = '',
                max_prefix = 56,
                md5 = '',
                project = equinix.services.metalv1.models.href.Href(
                    href = '', ),
                ranges = [
                    equinix.services.metalv1.models.global_bgp_range.GlobalBgpRange(
                        address_family = 56, 
                        href = '', 
                        id = '', 
                        project = equinix.services.metalv1.models.href.Href(
                            href = '', ), 
                        range = '', )
                    ],
                requested_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                route_object = '',
                sessions = [
                    equinix.services.metalv1.models.bgp_session.BgpSession(
                        address_family = 'ipv4', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        default_route = True, 
                        device = equinix.services.metalv1.models.href.Href(
                            href = '', ), 
                        href = '', 
                        id = '', 
                        learned_routes = [
                            '10.32.16.0/31'
                            ], 
                        status = 'up,down', 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                status = 'requested'
            )
        else:
            return BgpConfig(
        )
        """

    def testBgpConfig(self):
        """Test BgpConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class VrfCreateInput(BaseModel):
    """
    VrfCreateInput
    """ # noqa: E501
    bgp_dynamic_neighbors_bfd_enabled: Optional[StrictBool] = Field(default=None, description="Toggle BFD on dynamic bgp neighbors sessions")
    bgp_dynamic_neighbors_enabled: Optional[StrictBool] = Field(default=None, description="Toggle to enable the dynamic bgp neighbors feature on the VRF")
    bgp_dynamic_neighbors_export_route_map: Optional[StrictBool] = Field(default=None, description="Toggle to export the VRF route-map to the dynamic bgp neighbors")
    description: Optional[StrictStr] = None
    href: Optional[StrictStr] = None
    ip_ranges: Optional[List[StrictStr]] = Field(default=None, description="A list of CIDR network addresses. Like [\"10.0.0.0/16\", \"2001:d78::/59\"]. IPv4 blocks must be between /8 and /29 in size. IPv6 blocks must be between /59 and /64. A VRF\\'s IP ranges must be defined in order to create VRF IP Reservations, which can then be used for Metal Gateways or Virtual Circuits.")
    local_asn: Optional[Annotated[int, Field(le=4294967295, strict=True, ge=0)]] = None
    metro: StrictStr = Field(description="The UUID (or metro code) for the Metro in which to create this VRF.")
    name: StrictStr
    tags: Optional[List[StrictStr]] = None
    __properties: ClassVar[List[str]] = ["bgp_dynamic_neighbors_bfd_enabled", "bgp_dynamic_neighbors_enabled", "bgp_dynamic_neighbors_export_route_map", "description", "href", "ip_ranges", "local_asn", "metro", "name", "tags"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of VrfCreateInput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of VrfCreateInput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "bgp_dynamic_neighbors_bfd_enabled": obj.get("bgp_dynamic_neighbors_bfd_enabled"),
            "bgp_dynamic_neighbors_enabled": obj.get("bgp_dynamic_neighbors_enabled"),
            "bgp_dynamic_neighbors_export_route_map": obj.get("bgp_dynamic_neighbors_export_route_map"),
            "description": obj.get("description"),
            "href": obj.get("href"),
            "ip_ranges": obj.get("ip_ranges"),
            "local_asn": obj.get("local_asn"),
            "metro": obj.get("metro"),
            "name": obj.get("name"),
            "tags": obj.get("tags")
        })
        return _obj





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.vrf_ip_reservation_list import VrfIpReservationList

class TestVrfIpReservationList(unittest.TestCase):
    """VrfIpReservationList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> VrfIpReservationList:
        """Test VrfIpReservationList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `VrfIpReservationList`
        """
        model = VrfIpReservationList()
        if include_optional:
            return VrfIpReservationList(
                href = '',
                ip_addresses = [
                    equinix.services.metalv1.models.vrf_ip_reservation.VrfIpReservation(
                        address = '', 
                        address_family = 56, 
                        bill = True, 
                        cidr = 56, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        created_by = equinix.services.metalv1.models.href.Href(
                            href = '', ), 
                        customdata = equinix.services.metalv1.models.customdata.customdata(), 
                        details = '', 
                        gateway = '', 
                        href = '', 
                        id = '', 
                        manageable = True, 
                        management = True, 
                        metal_gateway = equinix.services.metalv1.models.metal_gateway_lite.MetalGatewayLite(
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            gateway_address = '10.1.2.1/27', 
                            href = '', 
                            id = '', 
                            state = 'ready', 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            vlan = 1001, ), 
                        metro = equinix.services.metalv1.models.metro.Metro(
                            code = '', 
                            country = '', 
                            href = '', 
                            id = '', 
                            name = '', ), 
                        netmask = '', 
                        network = '', 
                        project = equinix.services.metalv1.models.project.Project(
                            backend_transfer_enabled = True, 
                            bgp_config = equinix.services.metalv1.models.href.Href(
                                href = '', ), 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            customdata = equinix.services.metalv1.models.customdata.customdata(), 
                            devices = [
                                
                                ], 
                            href = '', 
                            id = '', 
                            invitations = [
                                
                                ], 
                            max_devices = equinix.services.metalv1.models.max_devices.max_devices(), 
                            members = [
                                
                                ], 
                            memberships = [
                                
                                ], 
                            name = '0', 
                            network_status = equinix.services.metalv1.models.network_status.network_status(), 
                            organization = , 
                            payment_method = , 
                            ssh_keys = [
                                
                                ], 
                            tags = [
                                ''
                                ], 
                            type = 'default', 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            url = '', 
                            volumes = [
                                
                                ], ), 
                        project_lite = equinix.services.metalv1.models.project.Project(
                            backend_transfer_enabled = True, 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            customdata = equinix.services.metalv1.models.customdata.customdata(), 
                            href = '', 
                            id = '', 
                            max_devices = equinix.services.metalv1.models.max_devices.max_devices(), 
                            name = '0', 
                            network_status = equinix.services.metalv1.models.network_status.network_status(), 
                            type = 'default', 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            url = '', ), 
                        public = True, 
                        state = '', 
                        tags = [
                            ''
                            ], 
                        type = 'vrf', 
                        vrf = equinix.services.metalv1.models.vrf.Vrf(
                            bgp_dynamic_neighbors_bfd_enabled = True, 
                            bgp_dynamic_neighbors_enabled = True, 
                            bgp_dynamic_neighbors_export_route_map = True, 
                            bill = True, 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            description = '', 
                            href = '', 
                            id = '', 
                            ip_ranges = [
                                ''
                                ], 
                            local_asn = 65000, 
                            name = '', 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            virtual_circuits = [
                                equinix.services.metalv1.models.vrf_virtual_circuit.VrfVirtualCircuit(
                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    customer_ip = '12.0.0.2', 
                                    customer_ipv6 = '2604:1380:4641:a00::6', 
                                    description = '', 
                                    href = '', 
                                    id = '', 
                                    md5 = '', 
                                    metal_ip = '12.0.0.1', 
                                    metal_ipv6 = '2604:1380:4641:a00::6', 
                                    name = '', 
                                    nni_vlan = 56, 
                                    peer_asn = 65000, 
                                    port = equinix.services.metalv1.models.interconnection_port.InterconnectionPort(
                                        href = '', 
                                        id = '', 
                                        link_status = '', 
                                        name = '', 
                                        role = 'primary', 
                                        speed = 56, 
                                        status = 'requested', 
                                        switch_id = '', ), 
                                    speed = 56, 
                                    status = 'pending', 
                                    subnet = '12.0.0.0/30', 
                                    subnet_ipv6 = '2604:1380:4641:a00::4/126', 
                                    type = 'vrf', 
                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    vrf = equinix.services.metalv1.models.vrf.Vrf(
                                        bgp_dynamic_neighbors_bfd_enabled = True, 
                                        bgp_dynamic_neighbors_enabled = True, 
                                        bgp_dynamic_neighbors_export_route_map = True, 
                                        bill = True, 
                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        description = '', 
                                        href = '', 
                                        id = '', 
                                        local_asn = 65000, 
                                        name = '', 
                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                ], ), )
                    ]
            )
        else:
            return VrfIpReservationList(
        )
        """

    def testVrfIpReservationList(self):
        """Test VrfIpReservationList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.metal_gateways_api import MetalGatewaysApi


class TestMetalGatewaysApi(unittest.TestCase):
    """MetalGatewaysApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MetalGatewaysApi()

    def tearDown(self) -> None:
        pass

    def test_create_bgp_dynamic_neighbor(self) -> None:
        """Test case for create_bgp_dynamic_neighbor

        Create a VRF BGP Dynamic Neighbor range
        """
        pass

    def test_create_metal_gateway(self) -> None:
        """Test case for create_metal_gateway

        Create a metal gateway
        """
        pass

    def test_create_metal_gateway_elastic_ip(self) -> None:
        """Test case for create_metal_gateway_elastic_ip

        Create a Metal Gateway Elastic IP
        """
        pass

    def test_delete_metal_gateway(self) -> None:
        """Test case for delete_metal_gateway

        Deletes the metal gateway
        """
        pass

    def test_find_metal_gateway_by_id(self) -> None:
        """Test case for find_metal_gateway_by_id

        Returns the metal gateway
        """
        pass

    def test_find_metal_gateways_by_project(self) -> None:
        """Test case for find_metal_gateways_by_project

        Returns all metal gateways for a project
        """
        pass

    def test_find_metal_gateways_by_project_all_pages(self):
        """Test case for find_metal_gateways_by_project_all_pages

        Returns all metal gateways for a project  # noqa: E501
        """
        pass

    def test_get_bgp_dynamic_neighbors(self) -> None:
        """Test case for get_bgp_dynamic_neighbors

        List BGP Dynamic Neighbors
        """
        pass

    def test_get_metal_gateway_elastic_ips(self) -> None:
        """Test case for get_metal_gateway_elastic_ips

        List Metal Gateway Elastic IPs
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from equinix.services.metalv1.models.metro import Metro
from equinix.services.metalv1.models.project import Project
from equinix.services.metalv1.models.user import User
from typing import Optional, Set
from typing_extensions import Self

class Vrf(BaseModel):
    """
    Vrf
    """ # noqa: E501
    bgp_dynamic_neighbors_bfd_enabled: Optional[StrictBool] = Field(default=None, description="Toggle BFD on dynamic bgp neighbors sessions")
    bgp_dynamic_neighbors_enabled: Optional[StrictBool] = Field(default=None, description="Toggle to enable the dynamic bgp neighbors feature on the VRF")
    bgp_dynamic_neighbors_export_route_map: Optional[StrictBool] = Field(default=None, description="Toggle to export the VRF route-map to the dynamic bgp neighbors")
    bill: Optional[StrictBool] = Field(default=False, description="True if the VRF is being billed. Usage will start when the first VRF Virtual Circuit is active, and will only stop when the VRF has been deleted.")
    created_at: Optional[datetime] = None
    created_by: Optional[User] = None
    description: Optional[StrictStr] = Field(default=None, description="Optional field that can be set to describe the VRF")
    href: Optional[StrictStr] = None
    id: Optional[StrictStr] = None
    ip_ranges: Optional[List[StrictStr]] = Field(default=None, description="A list of CIDR network addresses. Like [\"10.0.0.0/16\", \"2001:d78::/59\"].")
    local_asn: Optional[Annotated[int, Field(le=4294967295, strict=True, ge=0)]] = Field(default=None, description="A 4-byte ASN associated with the VRF.")
    metro: Optional[Metro] = None
    name: Optional[StrictStr] = None
    project: Optional[Project] = None
    tags: Optional[List[StrictStr]] = None
    updated_at: Optional[datetime] = None
    virtual_circuits: Optional[List[VrfVirtualCircuit]] = Field(default=None, description="Virtual circuits that are in the VRF")
    __properties: ClassVar[List[str]] = ["bgp_dynamic_neighbors_bfd_enabled", "bgp_dynamic_neighbors_enabled", "bgp_dynamic_neighbors_export_route_map", "bill", "created_at", "created_by", "description", "href", "id", "ip_ranges", "local_asn", "metro", "name", "project", "tags", "updated_at", "virtual_circuits"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Vrf from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of created_by
        if self.created_by:
            _dict['created_by'] = self.created_by.to_dict()
        # override the default output from pydantic by calling `to_dict()` of metro
        if self.metro:
            _dict['metro'] = self.metro.to_dict()
        # override the default output from pydantic by calling `to_dict()` of project
        if self.project:
            _dict['project'] = self.project.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in virtual_circuits (list)
        _items = []
        if self.virtual_circuits:
            for _item in self.virtual_circuits:
                if _item:
                    _items.append(_item.to_dict())
            _dict['virtual_circuits'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Vrf from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "bgp_dynamic_neighbors_bfd_enabled": obj.get("bgp_dynamic_neighbors_bfd_enabled"),
            "bgp_dynamic_neighbors_enabled": obj.get("bgp_dynamic_neighbors_enabled"),
            "bgp_dynamic_neighbors_export_route_map": obj.get("bgp_dynamic_neighbors_export_route_map"),
            "bill": obj.get("bill") if obj.get("bill") is not None else False,
            "created_at": obj.get("created_at"),
            "created_by": User.from_dict(obj["created_by"]) if obj.get("created_by") is not None else None,
            "description": obj.get("description"),
            "href": obj.get("href"),
            "id": obj.get("id"),
            "ip_ranges": obj.get("ip_ranges"),
            "local_asn": obj.get("local_asn"),
            "metro": Metro.from_dict(obj["metro"]) if obj.get("metro") is not None else None,
            "name": obj.get("name"),
            "project": Project.from_dict(obj["project"]) if obj.get("project") is not None else None,
            "tags": obj.get("tags"),
            "updated_at": obj.get("updated_at"),
            "virtual_circuits": [VrfVirtualCircuit.from_dict(_item) for _item in obj["virtual_circuits"]] if obj.get("virtual_circuits") is not None else None
        })
        return _obj

from equinix.services.metalv1.models.vrf_virtual_circuit import VrfVirtualCircuit
# TODO: Rewrite to not use raise_errors
Vrf.model_rebuild(raise_errors=False)




# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.spot_market_request_create_input_instance_parameters import SpotMarketRequestCreateInputInstanceParameters

class TestSpotMarketRequestCreateInputInstanceParameters(unittest.TestCase):
    """SpotMarketRequestCreateInputInstanceParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SpotMarketRequestCreateInputInstanceParameters:
        """Test SpotMarketRequestCreateInputInstanceParameters
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SpotMarketRequestCreateInputInstanceParameters`
        """
        model = SpotMarketRequestCreateInputInstanceParameters()
        if include_optional:
            return SpotMarketRequestCreateInputInstanceParameters(
                always_pxe = True,
                billing_cycle = '',
                customdata = equinix.services.metalv1.models.customdata.customdata(),
                description = '',
                features = [
                    ''
                    ],
                hostname = '',
                hostnames = [
                    ''
                    ],
                href = '',
                locked = True,
                no_ssh_keys = True,
                operating_system = '',
                plan = '',
                private_ipv4_subnet_size = 56,
                project_ssh_keys = [
                    ''
                    ],
                public_ipv4_subnet_size = 56,
                tags = [
                    ''
                    ],
                termination_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                user_ssh_keys = [
                    ''
                    ],
                userdata = ''
            )
        else:
            return SpotMarketRequestCreateInputInstanceParameters(
        )
        """

    def testSpotMarketRequestCreateInputInstanceParameters(self):
        """Test SpotMarketRequestCreateInputInstanceParameters"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.device_list import DeviceList

class TestDeviceList(unittest.TestCase):
    """DeviceList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DeviceList:
        """Test DeviceList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DeviceList`
        """
        model = DeviceList()
        if include_optional:
            return DeviceList(
                devices = [
                    equinix.services.metalv1.models.device.Device(
                        actions = [
                            equinix.services.metalv1.models.device_actions_inner.Device_actions_inner(
                                href = '', 
                                name = '', 
                                type = '', )
                            ], 
                        always_pxe = True, 
                        billing_cycle = '', 
                        bonding_mode = 56, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        created_by = null, 
                        customdata = { }, 
                        description = '', 
                        facility = equinix.services.metalv1.models.facility.Facility(
                            address = equinix.services.metalv1.models.address.Address(
                                address2 = '', 
                                city = '', 
                                coordinates = equinix.services.metalv1.models.coordinates.Coordinates(
                                    href = '', 
                                    latitude = '', 
                                    longitude = '', ), 
                                country = '', 
                                href = '', 
                                state = '', 
                                zip_code = '', ), 
                            code = '', 
                            features = ["baremetal","backend_transfer","global_ipv4"], 
                            href = '', 
                            id = '', 
                            ip_ranges = ["2604:1380::/36","147.75.192.0/21"], 
                            metro = null, 
                            name = '', ), 
                        firmware_set_id = '', 
                        hardware_reservation = equinix.services.metalv1.models.hardware_reservation.HardwareReservation(
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            custom_rate = 1050.5, 
                            device = equinix.services.metalv1.models.device.Device(
                                always_pxe = True, 
                                billing_cycle = '', 
                                bonding_mode = 56, 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                description = '', 
                                firmware_set_id = '', 
                                hostname = '', 
                                href = '', 
                                id = '', 
                                image_url = '', 
                                ip_addresses = [
                                    equinix.services.metalv1.models.ip_assignment.IPAssignment(
                                        address_family = 56, 
                                        assigned_to = equinix.services.metalv1.models.href.Href(
                                            href = '', ), 
                                        cidr = 56, 
                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        enabled = True, 
                                        gateway = '', 
                                        global_ip = True, 
                                        href = '', 
                                        id = '', 
                                        manageable = True, 
                                        management = True, 
                                        netmask = '', 
                                        network = '', 
                                        next_hop = '', 
                                        parent_block = equinix.services.metalv1.models.parent_block.ParentBlock(
                                            cidr = 56, 
                                            href = '', 
                                            netmask = '', 
                                            network = '', ), 
                                        public = True, 
                                        state = 'pending', )
                                    ], 
                                ipxe_script_url = '', 
                                iqn = '', 
                                locked = True, 
                                network_frozen = True, 
                                network_ports = [
                                    equinix.services.metalv1.models.port.Port(
                                        bond = equinix.services.metalv1.models.bond_port_data.BondPortData(
                                            href = '', 
                                            id = '', 
                                            name = '', ), 
                                        data = equinix.services.metalv1.models.port_data.PortData(
                                            bonded = True, 
                                            href = '', 
                                            mac = '', ), 
                                        disbond_operation_supported = True, 
                                        href = '', 
                                        id = '', 
                                        name = 'bond0', 
                                        native_virtual_network = equinix.services.metalv1.models.virtual_network.VirtualNetwork(
                                            assigned_to_virtual_circuit = True, 
                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            description = '', 
                                            href = '', 
                                            id = '', 
                                            instances = [
                                                
                                                ], 
                                            metal_gateways = [
                                                equinix.services.metalv1.models.metal_gateway_lite.MetalGatewayLite(
                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    gateway_address = '10.1.2.1/27', 
                                                    href = '', 
                                                    id = '', 
                                                    state = 'ready', 
                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    vlan = 1001, )
                                                ], 
                                            metro_code = '', 
                                            tags = [
                                                ''
                                                ], 
                                            vxlan = 56, ), 
                                        network_type = 'layer2-bonded', 
                                        type = 'NetworkPort', 
                                        virtual_networks = [
                                            equinix.services.metalv1.models.virtual_network.VirtualNetwork(
                                                assigned_to_virtual_circuit = True, 
                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                description = '', 
                                                href = '', 
                                                id = '', 
                                                metro_code = '', 
                                                vxlan = 56, )
                                            ], )
                                    ], 
                                operating_system = equinix.services.metalv1.models.operating_system.OperatingSystem(
                                    build_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                    default_operating_system = True, 
                                    deprecation_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                    distro = '', 
                                    distro_label = '', 
                                    end_of_life_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                    end_of_service_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                    href = '', 
                                    id = '', 
                                    licensed = True, 
                                    lifecycle_state = '', 
                                    name = '', 
                                    preinstallable = True, 
                                    pricing = equinix.services.metalv1.models.pricing.pricing(), 
                                    provisionable_on = [
                                        ''
                                        ], 
                                    release_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                    release_notes = '', 
                                    slug = '', 
                                    version = '', ), 
                                plan = equinix.services.metalv1.models.plan.Plan(
                                    available_in = [
                                        equinix.services.metalv1.models.plan_available_in_inner.Plan_available_in_inner(
                                            href = '', 
                                            price = equinix.services.metalv1.models.plan_available_in_inner_price.Plan_available_in_inner_price(
                                                hour = 1.23, 
                                                href = '', ), )
                                        ], 
                                    available_in_metros = [
                                        equinix.services.metalv1.models.plan_available_in_metros_inner.Plan_available_in_metros_inner(
                                            href = '', )
                                        ], 
                                    categories = [
                                        ''
                                        ], 
                                    class = 'm3.large.x86', 
                                    deployment_types = [
                                        'on_demand'
                                        ], 
                                    description = '', 
                                    href = '', 
                                    id = '', 
                                    legacy = True, 
                                    line = '', 
                                    name = '', 
                                    pricing = equinix.services.metalv1.models.pricing.pricing(), 
                                    slug = 'm3.large.x86', 
                                    specs = equinix.services.metalv1.models.plan_specs.Plan_specs(
                                        cpus = [
                                            equinix.services.metalv1.models.plan_specs_cpus_inner.Plan_specs_cpus_inner(
                                                count = 56, 
                                                href = '', 
                                                type = '', )
                                            ], 
                                        drives = [
                                            equinix.services.metalv1.models.plan_specs_drives_inner.Plan_specs_drives_inner(
                                                category = '', 
                                                count = 56, 
                                                href = '', 
                                                size = '3.84TB', 
                                                type = '', )
                                            ], 
                                        features = equinix.services.metalv1.models.plan_specs_features.Plan_specs_features(
                                            href = '', 
                                            raid = True, 
                                            txt = True, 
                                            uefi = True, ), 
                                        href = '', 
                                        memory = equinix.services.metalv1.models.plan_specs_memory.Plan_specs_memory(
                                            href = '', 
                                            total = '', ), 
                                        nics = [
                                            equinix.services.metalv1.models.plan_specs_nics_inner.Plan_specs_nics_inner(
                                                count = 2, 
                                                href = '', 
                                                type = '', )
                                            ], ), 
                                    type = 'standard', ), 
                                project = equinix.services.metalv1.models.project.Project(
                                    backend_transfer_enabled = True, 
                                    bgp_config = equinix.services.metalv1.models.href.Href(
                                        href = '', ), 
                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    devices = [
                                        
                                        ], 
                                    href = '', 
                                    id = '', 
                                    invitations = [
                                        
                                        ], 
                                    max_devices = equinix.services.metalv1.models.max_devices.max_devices(), 
                                    members = [
                                        
                                        ], 
                                    memberships = [
                                        
                                        ], 
                                    name = '0', 
                                    network_status = equinix.services.metalv1.models.network_status.network_status(), 
                                    organization = , 
                                    payment_method = , 
                                    ssh_keys = [
                                        
                                        ], 
                                    type = 'default', 
                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    url = '', 
                                    volumes = [
                                        
                                        ], ), 
                                project_lite = null, 
                                provisioning_events = [
                                    equinix.services.metalv1.models.event.Event(
                                        body = '', 
                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        href = '', 
                                        id = '', 
                                        interpolated = '', 
                                        ip = '', 
                                        modified_by = equinix.services.metalv1.models.modified_by.modified_by(), 
                                        relationships = [
                                            
                                            ], 
                                        state = '', 
                                        type = '', )
                                    ], 
                                provisioning_percentage = 1.337, 
                                root_password = '', 
                                short_id = '', 
                                sos = '', 
                                spot_instance = True, 
                                spot_price_max = 1.337, 
                                ssh_keys = [
                                    
                                    ], 
                                state = 'queued', 
                                storage = equinix.services.metalv1.models.storage.Storage(
                                    disks = [
                                        equinix.services.metalv1.models.disk.Disk(
                                            href = '', 
                                            partitions = [
                                                equinix.services.metalv1.models.partition.Partition(
                                                    href = '', 
                                                    label = '', 
                                                    number = 56, 
                                                    size = '', )
                                                ], 
                                            wipe_table = True, )
                                        ], 
                                    filesystems = [
                                        equinix.services.metalv1.models.filesystem.Filesystem(
                                            href = '', 
                                            mount = equinix.services.metalv1.models.mount.Mount(
                                                format = '', 
                                                href = '', 
                                                options = [
                                                    ''
                                                    ], 
                                                point = '', ), )
                                        ], 
                                    href = '', 
                                    raid = [
                                        equinix.services.metalv1.models.raid.Raid(
                                            href = '', 
                                            level = '', 
                                            name = '', )
                                        ], ), 
                                switch_uuid = '', 
                                tags = [
                                    ''
                                    ], 
                                termination_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                user = '', 
                                userdata = '', 
                                volumes = [
                                    
                                    ], ), 
                            href = '', 
                            id = '', 
                            need_of_service = True, 
                            plan = equinix.services.metalv1.models.plan.Plan(
                                class = 'm3.large.x86', 
                                description = '', 
                                href = '', 
                                id = '', 
                                legacy = True, 
                                line = '', 
                                name = '', 
                                pricing = equinix.services.metalv1.models.pricing.pricing(), 
                                slug = 'm3.large.x86', 
                                type = 'standard', ), 
                            project = equinix.services.metalv1.models.project.Project(
                                backend_transfer_enabled = True, 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                href = '', 
                                id = '', 
                                max_devices = equinix.services.metalv1.models.max_devices.max_devices(), 
                                name = '0', 
                                network_status = equinix.services.metalv1.models.network_status.network_status(), 
                                type = 'default', 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                url = '', ), 
                            provisionable = True, 
                            short_id = '', 
                            spare = True, 
                            switch_uuid = '', 
                            termination_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        hostname = '', 
                        href = '', 
                        id = '', 
                        image_url = '', 
                        ip_addresses = [
                            equinix.services.metalv1.models.ip_assignment.IPAssignment(
                                address_family = 56, 
                                assigned_to = , 
                                cidr = 56, 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                enabled = True, 
                                gateway = '', 
                                global_ip = True, 
                                href = '', 
                                id = '', 
                                manageable = True, 
                                management = True, 
                                netmask = '', 
                                network = '', 
                                next_hop = '', 
                                public = True, 
                                state = 'pending', )
                            ], 
                        ipxe_script_url = '', 
                        iqn = '', 
                        locked = True, 
                        metro = null, 
                        network_frozen = True, 
                        network_ports = [
                            equinix.services.metalv1.models.port.Port(
                                disbond_operation_supported = True, 
                                href = '', 
                                id = '', 
                                name = 'bond0', 
                                network_type = 'layer2-bonded', 
                                type = 'NetworkPort', )
                            ], 
                        operating_system = equinix.services.metalv1.models.operating_system.OperatingSystem(
                            build_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                            default_operating_system = True, 
                            deprecation_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                            distro = '', 
                            distro_label = '', 
                            end_of_life_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                            end_of_service_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                            href = '', 
                            id = '', 
                            licensed = True, 
                            lifecycle_state = '', 
                            name = '', 
                            preinstallable = True, 
                            pricing = equinix.services.metalv1.models.pricing.pricing(), 
                            release_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                            release_notes = '', 
                            slug = '', 
                            version = '', ), 
                        plan = , 
                        project = , 
                        project_lite = null, 
                        provisioning_events = [
                            equinix.services.metalv1.models.event.Event(
                                body = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                href = '', 
                                id = '', 
                                interpolated = '', 
                                ip = '', 
                                modified_by = equinix.services.metalv1.models.modified_by.modified_by(), 
                                state = '', 
                                type = '', )
                            ], 
                        provisioning_percentage = 1.337, 
                        root_password = '', 
                        short_id = '', 
                        sos = '', 
                        spot_instance = True, 
                        spot_price_max = 1.337, 
                        ssh_keys = , 
                        state = 'queued', 
                        storage = equinix.services.metalv1.models.storage.Storage(
                            href = '', ), 
                        switch_uuid = '', 
                        tags = , 
                        termination_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        user = '', 
                        userdata = '', 
                        volumes = , )
                    ],
                href = '',
                meta = equinix.services.metalv1.models.meta.Meta(
                    current_page = 56, 
                    first = equinix.services.metalv1.models.href.Href(
                        href = '', ), 
                    href = '', 
                    last = equinix.services.metalv1.models.href.Href(
                        href = '', ), 
                    last_page = 56, 
                    next = , 
                    previous = , 
                    self = , 
                    total = 56, )
            )
        else:
            return DeviceList(
        )
        """

    def testDeviceList(self):
        """Test DeviceList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.storage import Storage

class TestStorage(unittest.TestCase):
    """Storage unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Storage:
        """Test Storage
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Storage`
        """
        model = Storage()
        if include_optional:
            return Storage(
                disks = [
                    equinix.services.metalv1.models.disk.Disk(
                        device = '', 
                        href = '', 
                        partitions = [
                            equinix.services.metalv1.models.partition.Partition(
                                href = '', 
                                label = '', 
                                number = 56, 
                                size = '', )
                            ], 
                        wipe_table = True, )
                    ],
                filesystems = [
                    equinix.services.metalv1.models.filesystem.Filesystem(
                        href = '', 
                        mount = equinix.services.metalv1.models.mount.Mount(
                            device = '', 
                            format = '', 
                            href = '', 
                            options = [
                                ''
                                ], 
                            point = '', ), )
                    ],
                href = '',
                raid = [
                    equinix.services.metalv1.models.raid.Raid(
                        devices = [
                            ''
                            ], 
                        href = '', 
                        level = '', 
                        name = '', )
                    ]
            )
        else:
            return Storage(
        )
        """

    def testStorage(self):
        """Test Storage"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Equinix Fabric API v4

    Equinix Fabric is an advanced software-defined interconnection solution that enables you to directly, securely and dynamically connect to distributed infrastructure and digital ecosystems on platform Equinix via a single port, Customers can use Fabric to connect to: </br> 1. Cloud Service Providers - Clouds, network and other service providers.  </br> 2. Enterprises - Other Equinix customers, vendors and partners.  </br> 3. Myself - Another customer instance deployed at Equinix. </br> </br> <b>Integrations (SDKs, Tools) links:</b> </br> <a href=\"https://deploy.equinix.com/labs/fabric-java\\\">Fabric Java SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-go\\\">Fabric Go SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-python\\\">Fabric Python SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-provider-equinix\\\">Equinix Terraform Provider</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-equinix-fabric\\\">Fabric Terraform Modules</a> </br> <a href=\"https://deploy.equinix.com/labs/pulumi-provider-equinix/\">Equinix Pulumi Provider</a> </br>

    The version of the OpenAPI document: 4.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.fabricv4.models.physical_port import PhysicalPort

class TestPhysicalPort(unittest.TestCase):
    """PhysicalPort unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PhysicalPort:
        """Test PhysicalPort
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PhysicalPort`
        """
        model = PhysicalPort()
        if include_optional:
            return PhysicalPort(
                href = '',
                type = 'XF_PHYSICAL_PORT',
                id = 56,
                state = 'PENDING',
                account = equinix.services.fabricv4.models.simplified_account.SimplifiedAccount(
                    account_number = 56, 
                    account_name = '', 
                    org_id = 56, 
                    organization_name = '', 
                    global_org_id = '', 
                    global_organization_name = '', 
                    ucm_id = '', 
                    global_cust_id = '', 
                    reseller_account_number = 56, 
                    reseller_account_name = '', 
                    reseller_ucm_id = '', 
                    reseller_org_id = 56, ),
                interface_speed = 0,
                interface_type = '',
                uuid = '',
                tether = equinix.services.fabricv4.models.port_tether.PortTether(
                    cross_connect_id = '', 
                    cabinet_number = '', 
                    system_name = '', 
                    patch_panel = '', 
                    patch_panel_port_a = '', 
                    patch_panel_port_b = '', 
                    ibx = '', ),
                demarcation_point = equinix.services.fabricv4.models.port_demarcation_point.PortDemarcationPoint(
                    cabinet_unique_space_id = '', 
                    cage_unique_space_id = '', 
                    patch_panel = '', 
                    patch_panel_name = '', 
                    patch_panel_port_a = '', 
                    patch_panel_port_b = '', 
                    connector_type = '', 
                    ibx = '', ),
                settings = equinix.services.fabricv4.models.physical_port_settings.PhysicalPortSettings(
                    error_message = '', 
                    package_type = '', ),
                interface = equinix.services.fabricv4.models.port_interface.PortInterface(
                    type = '', ),
                notifications = [
                    equinix.services.fabricv4.models.port_notification.PortNotification(
                        type = 'NOTIFICATION', 
                        registered_users = [
                            ''
                            ], )
                    ],
                additional_info = [
                    equinix.services.fabricv4.models.port_additional_info.PortAdditionalInfo(
                        key = '', 
                        value = '', )
                    ],
                order = equinix.services.fabricv4.models.port_order.PortOrder(
                    purchase_order = equinix.services.fabricv4.models.port_order_purchase_order.PortOrder_purchaseOrder(
                        number = '', 
                        amount = '', 
                        start_date = '', 
                        end_date = '', 
                        attachment_id = '', 
                        selection_type = 'EXEMPTION', 
                        type = 'EXEMPTION', ), 
                    order_id = '', 
                    customer_reference_id = '', 
                    order_number = '', 
                    uuid = '', 
                    signature = equinix.services.fabricv4.models.port_order_signature.PortOrder_signature(
                        signatory = 'DELEGATE', 
                        delegate = equinix.services.fabricv4.models.port_order_signature_delegate.PortOrder_signature_delegate(
                            first_name = '', 
                            last_name = '', 
                            email = '', ), ), ),
                operation = equinix.services.fabricv4.models.port_operation.PortOperation(
                    operational_status = 'UP', 
                    connection_count = 56, 
                    evpl_vc_count = 56, 
                    fg_vc_count = 56, 
                    access_vc_count = 56, 
                    op_status_changed_at = '2020-11-06T07:00Z', ),
                loas = [
                    equinix.services.fabricv4.models.port_loa.PortLoa(
                        uuid = '', 
                        href = '', 
                        type = 'CTR_LOA', )
                    ]
            )
        else:
            return PhysicalPort(
        )
        """

    def testPhysicalPort(self):
        """Test PhysicalPort"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Equinix Fabric API v4

    Equinix Fabric is an advanced software-defined interconnection solution that enables you to directly, securely and dynamically connect to distributed infrastructure and digital ecosystems on platform Equinix via a single port, Customers can use Fabric to connect to: </br> 1. Cloud Service Providers - Clouds, network and other service providers.  </br> 2. Enterprises - Other Equinix customers, vendors and partners.  </br> 3. Myself - Another customer instance deployed at Equinix. </br> </br> <b>Integrations (SDKs, Tools) links:</b> </br> <a href=\"https://deploy.equinix.com/labs/fabric-java\\\">Fabric Java SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-go\\\">Fabric Go SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-python\\\">Fabric Python SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-provider-equinix\\\">Equinix Terraform Provider</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-equinix-fabric\\\">Fabric Terraform Modules</a> </br> <a href=\"https://deploy.equinix.com/labs/pulumi-provider-equinix/\">Equinix Pulumi Provider</a> </br>

    The version of the OpenAPI document: 4.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from equinix.services.fabricv4.models.custom_field import CustomField
from equinix.services.fabricv4.models.marketing_info import MarketingInfo
from equinix.services.fabricv4.models.project import Project
from equinix.services.fabricv4.models.service_metro import ServiceMetro
from equinix.services.fabricv4.models.service_profile_access_point_colo import ServiceProfileAccessPointCOLO
from equinix.services.fabricv4.models.service_profile_access_point_type import ServiceProfileAccessPointType
from equinix.services.fabricv4.models.service_profile_access_point_vd import ServiceProfileAccessPointVD
from equinix.services.fabricv4.models.service_profile_type_enum import ServiceProfileTypeEnum
from equinix.services.fabricv4.models.service_profile_visibility_enum import ServiceProfileVisibilityEnum
from equinix.services.fabricv4.models.simplified_notification import SimplifiedNotification
from typing import Optional, Set
from typing_extensions import Self

class ServiceProfileRequest(BaseModel):
    """
    Service Profile is a software definition for a named provider service and it's network connectivity requirements. This includes the basic marketing information and one or more sets of access points (a set per each access point type) fulfilling the provider service. 
    """ # noqa: E501
    project: Optional[Project] = None
    href: Optional[StrictStr] = Field(default=None, description="Service Profile URI response attribute")
    type: ServiceProfileTypeEnum
    name: Annotated[str, Field(strict=True, max_length=50)] = Field(description="Customer-assigned service profile name")
    uuid: Optional[StrictStr] = Field(default=None, description="Equinix-assigned service profile identifier")
    description: StrictStr = Field(description="User-provided service description should be of maximum length 375")
    notifications: Optional[List[SimplifiedNotification]] = Field(default=None, description="Recipients of notifications on service profile change")
    tags: Optional[List[StrictStr]] = None
    visibility: Optional[ServiceProfileVisibilityEnum] = None
    allowed_emails: Optional[List[StrictStr]] = Field(default=None, alias="allowedEmails")
    access_point_type_configs: Optional[Annotated[List[ServiceProfileAccessPointType], Field(min_length=1)]] = Field(default=None, alias="accessPointTypeConfigs")
    custom_fields: Optional[List[CustomField]] = Field(default=None, alias="customFields")
    marketing_info: Optional[MarketingInfo] = Field(default=None, alias="marketingInfo")
    ports: Optional[List[ServiceProfileAccessPointCOLO]] = None
    virtual_devices: Optional[List[ServiceProfileAccessPointVD]] = Field(default=None, alias="virtualDevices")
    metros: Optional[List[ServiceMetro]] = Field(default=None, description="Derived response attribute.")
    self_profile: Optional[StrictBool] = Field(default=None, description="response attribute indicates whether the profile belongs to the same organization as the api-invoker.", alias="selfProfile")
    project_id: Optional[StrictStr] = Field(default=None, alias="projectId")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["href", "type", "name", "uuid", "description", "notifications", "tags", "visibility", "allowedEmails", "accessPointTypeConfigs", "customFields", "marketingInfo", "ports", "virtualDevices", "metros", "selfProfile", "projectId"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServiceProfileRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "href",
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in notifications (list)
        _items = []
        if self.notifications:
            for _item in self.notifications:
                if _item:
                    _items.append(_item.to_dict())
            _dict['notifications'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in access_point_type_configs (list)
        _items = []
        if self.access_point_type_configs:
            for _item in self.access_point_type_configs:
                if _item:
                    _items.append(_item.to_dict())
            _dict['accessPointTypeConfigs'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in custom_fields (list)
        _items = []
        if self.custom_fields:
            for _item in self.custom_fields:
                if _item:
                    _items.append(_item.to_dict())
            _dict['customFields'] = _items
        # override the default output from pydantic by calling `to_dict()` of marketing_info
        if self.marketing_info:
            _dict['marketingInfo'] = self.marketing_info.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in ports (list)
        _items = []
        if self.ports:
            for _item in self.ports:
                if _item:
                    _items.append(_item.to_dict())
            _dict['ports'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in virtual_devices (list)
        _items = []
        if self.virtual_devices:
            for _item in self.virtual_devices:
                if _item:
                    _items.append(_item.to_dict())
            _dict['virtualDevices'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in metros (list)
        _items = []
        if self.metros:
            for _item in self.metros:
                if _item:
                    _items.append(_item.to_dict())
            _dict['metros'] = _items
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServiceProfileRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "href": obj.get("href"),
            "type": obj.get("type"),
            "name": obj.get("name"),
            "uuid": obj.get("uuid"),
            "description": obj.get("description"),
            "notifications": [SimplifiedNotification.from_dict(_item) for _item in obj["notifications"]] if obj.get("notifications") is not None else None,
            "tags": obj.get("tags"),
            "visibility": obj.get("visibility"),
            "allowedEmails": obj.get("allowedEmails"),
            "accessPointTypeConfigs": [ServiceProfileAccessPointType.from_dict(_item) for _item in obj["accessPointTypeConfigs"]] if obj.get("accessPointTypeConfigs") is not None else None,
            "customFields": [CustomField.from_dict(_item) for _item in obj["customFields"]] if obj.get("customFields") is not None else None,
            "marketingInfo": MarketingInfo.from_dict(obj["marketingInfo"]) if obj.get("marketingInfo") is not None else None,
            "ports": [ServiceProfileAccessPointCOLO.from_dict(_item) for _item in obj["ports"]] if obj.get("ports") is not None else None,
            "virtualDevices": [ServiceProfileAccessPointVD.from_dict(_item) for _item in obj["virtualDevices"]] if obj.get("virtualDevices") is not None else None,
            "metros": [ServiceMetro.from_dict(_item) for _item in obj["metros"]] if obj.get("metros") is not None else None,
            "selfProfile": obj.get("selfProfile"),
            "projectId": obj.get("projectId")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.self_service_reservation_response import SelfServiceReservationResponse

class TestSelfServiceReservationResponse(unittest.TestCase):
    """SelfServiceReservationResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SelfServiceReservationResponse:
        """Test SelfServiceReservationResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SelfServiceReservationResponse`
        """
        model = SelfServiceReservationResponse()
        if include_optional:
            return SelfServiceReservationResponse(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                href = '',
                item = [
                    equinix.services.metalv1.models.self_service_reservation_item_response.SelfServiceReservationItemResponse(
                        amount = 1.337, 
                        href = '', 
                        id = '', 
                        metro_code = '', 
                        metro_id = '', 
                        metro_name = '', 
                        plan = equinix.services.metalv1.models.plan.Plan(
                            available_in = [
                                equinix.services.metalv1.models.plan_available_in_inner.Plan_available_in_inner(
                                    href = '', 
                                    price = equinix.services.metalv1.models.plan_available_in_inner_price.Plan_available_in_inner_price(
                                        hour = 1.23, 
                                        href = '', ), )
                                ], 
                            available_in_metros = [
                                equinix.services.metalv1.models.plan_available_in_metros_inner.Plan_available_in_metros_inner(
                                    href = '', )
                                ], 
                            categories = [
                                ''
                                ], 
                            class = 'm3.large.x86', 
                            deployment_types = [
                                'on_demand'
                                ], 
                            description = '', 
                            href = '', 
                            id = '', 
                            legacy = True, 
                            line = '', 
                            name = '', 
                            pricing = equinix.services.metalv1.models.pricing.pricing(), 
                            slug = 'm3.large.x86', 
                            specs = equinix.services.metalv1.models.plan_specs.Plan_specs(
                                cpus = [
                                    equinix.services.metalv1.models.plan_specs_cpus_inner.Plan_specs_cpus_inner(
                                        count = 56, 
                                        href = '', 
                                        type = '', )
                                    ], 
                                drives = [
                                    equinix.services.metalv1.models.plan_specs_drives_inner.Plan_specs_drives_inner(
                                        category = '', 
                                        count = 56, 
                                        href = '', 
                                        size = '3.84TB', 
                                        type = '', )
                                    ], 
                                features = equinix.services.metalv1.models.plan_specs_features.Plan_specs_features(
                                    href = '', 
                                    raid = True, 
                                    txt = True, 
                                    uefi = True, ), 
                                href = '', 
                                memory = equinix.services.metalv1.models.plan_specs_memory.Plan_specs_memory(
                                    href = '', 
                                    total = '', ), 
                                nics = [
                                    equinix.services.metalv1.models.plan_specs_nics_inner.Plan_specs_nics_inner(
                                        count = 2, 
                                        href = '', 
                                        type = '', )
                                    ], ), 
                            type = 'standard', ), 
                        plan_categories = [
                            ''
                            ], 
                        plan_id = '', 
                        plan_name = '', 
                        plan_slug = '', 
                        quantity = 56, 
                        term = '', )
                    ],
                notes = '',
                organization = '',
                organization_id = '',
                period = equinix.services.metalv1.models.create_self_service_reservation_request_period.CreateSelfServiceReservationRequest_period(
                    count = 12, 
                    href = '', 
                    unit = 'monthly', ),
                project = '',
                project_id = '',
                start_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                status = '',
                total_cost = 56
            )
        else:
            return SelfServiceReservationResponse(
        )
        """

    def testSelfServiceReservationResponse(self):
        """Test SelfServiceReservationResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Equinix Fabric API v4

    Equinix Fabric is an advanced software-defined interconnection solution that enables you to directly, securely and dynamically connect to distributed infrastructure and digital ecosystems on platform Equinix via a single port, Customers can use Fabric to connect to: </br> 1. Cloud Service Providers - Clouds, network and other service providers.  </br> 2. Enterprises - Other Equinix customers, vendors and partners.  </br> 3. Myself - Another customer instance deployed at Equinix. </br> </br> <b>Integrations (SDKs, Tools) links:</b> </br> <a href=\"https://deploy.equinix.com/labs/fabric-java\\\">Fabric Java SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-go\\\">Fabric Go SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-python\\\">Fabric Python SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-provider-equinix\\\">Equinix Terraform Provider</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-equinix-fabric\\\">Fabric Terraform Modules</a> </br> <a href=\"https://deploy.equinix.com/labs/pulumi-provider-equinix/\">Equinix Pulumi Provider</a> </br>

    The version of the OpenAPI document: 4.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from equinix.services.fabricv4.models.ptp_advance_configuration_log_announce_interval import PtpAdvanceConfigurationLogAnnounceInterval
from equinix.services.fabricv4.models.ptp_advance_configuration_log_delay_req_interval import PtpAdvanceConfigurationLogDelayReqInterval
from equinix.services.fabricv4.models.ptp_advance_configuration_log_sync_interval import PtpAdvanceConfigurationLogSyncInterval
from equinix.services.fabricv4.models.ptp_advance_configuration_time_scale import PtpAdvanceConfigurationTimeScale
from equinix.services.fabricv4.models.ptp_advance_configuration_transport_mode import PtpAdvanceConfigurationTransportMode
from typing import Optional, Set
from typing_extensions import Self

class PtpAdvanceConfiguration(BaseModel):
    """
    PTP Advanced Configuration.
    """ # noqa: E501
    time_scale: Optional[PtpAdvanceConfigurationTimeScale] = Field(default=None, alias="timeScale")
    domain: Optional[Annotated[int, Field(le=127, strict=True, ge=0)]] = Field(default=None, description="The PTP domain value.")
    priority1: Optional[Annotated[int, Field(le=248, strict=True, ge=0)]] = Field(default=None, description="The priority1 value determines the best primary clock, Lower value indicates higher priority.")
    priority2: Optional[Annotated[int, Field(le=248, strict=True, ge=0)]] = Field(default=None, description="The priority2 value differentiates and prioritizes the primary clock to avoid confusion when priority1-value is the same for different primary clocks in a network.")
    log_announce_interval: Optional[PtpAdvanceConfigurationLogAnnounceInterval] = Field(default=None, alias="logAnnounceInterval")
    log_sync_interval: Optional[PtpAdvanceConfigurationLogSyncInterval] = Field(default=None, alias="logSyncInterval")
    log_delay_req_interval: Optional[PtpAdvanceConfigurationLogDelayReqInterval] = Field(default=None, alias="logDelayReqInterval")
    transport_mode: Optional[PtpAdvanceConfigurationTransportMode] = Field(default=None, alias="transportMode")
    grant_time: Optional[Annotated[int, Field(le=7200, strict=True, ge=30)]] = Field(default=None, description="Unicast Grant Time in seconds. For Multicast and Hybrid transport modes, grant time defaults to 300 seconds. For Unicast mode, grant time can be between 30 to 7200.", alias="grantTime")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["timeScale", "domain", "priority1", "priority2", "logAnnounceInterval", "logSyncInterval", "logDelayReqInterval", "transportMode", "grantTime"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PtpAdvanceConfiguration from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PtpAdvanceConfiguration from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "timeScale": obj.get("timeScale"),
            "domain": obj.get("domain"),
            "priority1": obj.get("priority1"),
            "priority2": obj.get("priority2"),
            "logAnnounceInterval": obj.get("logAnnounceInterval"),
            "logSyncInterval": obj.get("logSyncInterval"),
            "logDelayReqInterval": obj.get("logDelayReqInterval"),
            "transportMode": obj.get("transportMode"),
            "grantTime": obj.get("grantTime")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.events_api import EventsApi


class TestEventsApi(unittest.TestCase):
    """EventsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = EventsApi()

    def tearDown(self) -> None:
        pass

    def test_find_device_events(self) -> None:
        """Test case for find_device_events

        Retrieve device's events
        """
        pass

    def test_find_device_events_all_pages(self):
        """Test case for find_device_events_all_pages

        Retrieve device's events  # noqa: E501
        """
        pass

    def test_find_event_by_id(self) -> None:
        """Test case for find_event_by_id

        Retrieve an event
        """
        pass

    def test_find_events(self) -> None:
        """Test case for find_events

        Retrieve current user's events
        """
        pass

    def test_find_events_all_pages(self):
        """Test case for find_events_all_pages

        Retrieve current user's events  # noqa: E501
        """
        pass

    def test_find_interconnection_events(self) -> None:
        """Test case for find_interconnection_events

        Retrieve interconnection events
        """
        pass

    def test_find_interconnection_events_all_pages(self):
        """Test case for find_interconnection_events_all_pages

        Retrieve interconnection events  # noqa: E501
        """
        pass

    def test_find_interconnection_port_events(self) -> None:
        """Test case for find_interconnection_port_events

        Retrieve interconnection port events
        """
        pass

    def test_find_organization_events(self) -> None:
        """Test case for find_organization_events

        Retrieve organization's events
        """
        pass

    def test_find_organization_events_all_pages(self):
        """Test case for find_organization_events_all_pages

        Retrieve organization's events  # noqa: E501
        """
        pass

    def test_find_project_events(self) -> None:
        """Test case for find_project_events

        Retrieve project's events
        """
        pass

    def test_find_project_events_all_pages(self):
        """Test case for find_project_events_all_pages

        Retrieve project's events  # noqa: E501
        """
        pass

    def test_find_virtual_circuit_events(self) -> None:
        """Test case for find_virtual_circuit_events

        Retrieve virtual circuit events
        """
        pass

    def test_find_vrf_route_events(self) -> None:
        """Test case for find_vrf_route_events

        Retrieve VRF route events
        """
        pass


if __name__ == '__main__':
    unittest.main()
